@@ -16,7 +16,7 @@ use EPublisher::Utils::PPI qw(extract_pod);
 
 our @ISA = qw( EPublisher::Source::Base );
 
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 sub load_source{
     my ($self) = @_;
@@ -32,7 +32,7 @@ sub load_source{
     return if !$mod;
     return if !$mod->file;
 
-    my $pod      = extract_pod( $mod->file );
+    my $pod      = extract_pod( $mod->file, $self->_config );
     my $filename = File::Basename::basename( $mod->file );
     my $title    = $options->{name};
 
@@ -60,7 +60,7 @@ EPublisher::Source::Plugin::Module - Module source plugin
 
 =head1 VERSION
 
-version 0.6
+version 0.7
 
 =head1 SYNOPSIS
 
